@@ -8,14 +8,17 @@
 
 from __future__ import annotations
 
+import asyncio
 import enum
 
 from typing import TYPE_CHECKING
 
+from sdsstools.utils import cancel_task
+
 from hal import config
 from hal.exceptions import HALError
 
-from . import HALHelper
+from . import SpectrographHelper
 
 
 if TYPE_CHECKING:
@@ -25,13 +28,12 @@ if TYPE_CHECKING:
 __all__ = ["APOGEEHelper"]
 
 
-class APOGEEHelper(HALHelper):
+class APOGEEHelper(SpectrographHelper):
     """APOGEE instrument helper."""
 
     name = "apogee"
 
     def __init__(self, actor: HALActor):
-
         super().__init__(actor)
 
         self.gang_helper = APOGEEGangHelper(actor)
@@ -199,22 +201,27 @@ class APOGEEHelper(HALHelper):
     def is_exposing(self):
         """Returns `True` if APOGEE is exposing or stopping."""
 
-        exposure_state = self.actor.models["apogee"]["exposureState"]
+        state = self.get_exposure_state()
 
-        if exposure_state.value is None or None in exposure_state.value:
-            raise ValueError("Unknown APOGEE exposure state.")
-
-        state = exposure_state.value[0].lower()
         if state in ["exposing", "stopping"]:
             return True
         else:
             return False
 
+    def get_exposure_state(self) -> str | None:
+
+        exposure_state = self.actor.models["apogee"]["exposureState"]
+
+        if exposure_state.value is None or None in exposure_state.value:
+            raise ValueError("Unknown APOGEE exposure state.")
+
+        return exposure_state.value[0].lower()
+
     async def expose(
         self,
         command: HALCommandType,
         exp_time: float,
-        exp_type: str = "dark",
+        exp_type: str = "object",
         dither_position: str | None = None,
     ):
         """Exposes APOGEE.
@@ -283,6 +290,9 @@ class APOGEEHelper(HALHelper):
             if dither_sequence not in ["AB", "BA", "AA", "BB"]:
                 raise HALError(f"Invalid dither sequence {dither_sequence}.")
 
+        self._exposure_time_remaining = exp_time * len(dither_sequence)
+        self._exposure_time_remaining_timer = asyncio.create_task(self._timer())
+
         for dither_position in dither_sequence:
             await self.expose(
                 command,
@@ -291,16 +301,29 @@ class APOGEEHelper(HALHelper):
                 dither_position=dither_position,
             )
 
+        await cancel_task(self._exposure_time_remaining_timer)
+
+    async def abort(self, command: HALCommandType):
+        """Aborts the ongoing exposure."""
+
+        if not self.is_exposing():
+            return True
+
+        await self._send_command(command, "apogee", "expose stop", time_limit=60)
+        await self.shutter(command, open=False, shutter="apogee")
+
+        return True
+
 
 class APOGEEGangHelper:
     """Helper for the APOGEE gang connector."""
 
     def __init__(self, actor: HALActor):
-
         self.actor = actor
         self.flag: APOGEEGang = APOGEEGang.UNKNWON
 
-        actor.models["mcp"]["apogeeGang"].register_callback(self._update_flag)
+        if self.actor.observatory == "APO":
+            actor.models["mcp"]["apogeeGang"].register_callback(self._update_flag)
 
     async def _update_flag(self, value: list):
         """Callback to update the gang connector flag."""
