@@ -12,10 +12,12 @@ import asyncio
 
 from typing import TYPE_CHECKING
 
+from sdsstools.utils import cancel_task
+
 from hal import config
 from hal.exceptions import HALError
 
-from . import HALHelper
+from . import SpectrographHelper
 
 
 if TYPE_CHECKING:
@@ -25,7 +27,7 @@ if TYPE_CHECKING:
 __all__ = ["BOSSHelper"]
 
 
-class BOSSHelper(HALHelper):
+class BOSSHelper(SpectrographHelper):
     """Control for BOSS spectrograph."""
 
     __readout_pending: bool = False
@@ -70,7 +72,7 @@ class BOSSHelper(HALHelper):
 
             return exposure_state
 
-    def is_exposing(self):
+    def is_exposing(self, reading_ok: bool = True):
         """Returns `True` if the BOSS spectrograph is currently exposing."""
 
         state = self.get_exposure_state()
@@ -78,6 +80,8 @@ class BOSSHelper(HALHelper):
         if self.actor.observatory == "APO":
             if state in ["idle", "aborted"]:
                 return False
+            if reading_ok and state in ["reading", "prereading"]:
+                return False
         else:
             if "IDLE" in state.value and "READOUT_PENDING" not in state.value:
                 return False
@@ -108,11 +112,14 @@ class BOSSHelper(HALHelper):
     ):
         """Exposes BOSS. If ``readout=False``, does not read the exposure."""
 
-        if self.readout_pending is not False:
+        if self.readout_pending is not False or self.is_exposing():
             raise HALError(
                 "Cannot expose. The camera is exposing or a readout is pending."
             )
 
+        self._exposure_time_remaining = exp_time
+        self._exposure_time_remaining_timer = asyncio.create_task(self._timer())
+
         if self.actor.observatory == "APO":
             await self._expose_boss_icc(
                 command,
@@ -130,6 +137,8 @@ class BOSSHelper(HALHelper):
                 read_async=read_async,
             )
 
+        await cancel_task(self._exposure_time_remaining_timer)
+
     async def _expose_boss_icc(
         self,
         command: HALCommandType,
@@ -241,3 +250,24 @@ class BOSSHelper(HALHelper):
             )
 
         self.clear_readout()
+
+    async def abort(self, command: HALCommandType):
+        """Aborts the ongoing exposure."""
+
+        if not self.is_exposing():
+            command.warning("No BOSS exposure to abort.")
+            return True
+
+        if self.actor.observatory == "LCO":
+            await self._send_command(command, "yao", "abort --reset", time_limit=60)
+            await self._send_command(
+                command,
+                "yao",
+                "mech close shutter",
+                time_limit=20,
+            )
+        else:
+            await self._send_command(command, "boss", "exposure abort", time_limit=60)
+            await self._send_command(command, "boss", "clearExposure", time_limit=30)
+
+        return True
