@@ -15,6 +15,8 @@ from contextlib import suppress
 from dataclasses import dataclass
 from time import time
 
+from typing import TYPE_CHECKING
+
 import numpy
 
 from hal import config
@@ -22,6 +24,10 @@ from hal.exceptions import MacroError
 from hal.macros import Macro
 
 
+if TYPE_CHECKING:
+    from hal.helpers.jaeger import Configuration
+
+
 __all__ = ["ExposeMacro"]
 
 
@@ -79,6 +85,8 @@ class ExposeHelper:
         self._apogee_exp_start_time: float = 0
         self._boss_exp_start_time: float = 0
 
+        self.etr: float = 0.0
+
         self.interval: float = 10
         self._monitor_task: asyncio.Task | None = None
 
@@ -413,6 +421,8 @@ class ExposeHelper:
 
             self.macro.command.debug(exposure_state_boss=list(state_boss.values()))
 
+        self.etr = max(state_apogee["etr"], state_boss["etr"])
+
 
 class ExposeMacro(Macro):
     """Takes a science exposure with APOGEE and/or BOSS."""
@@ -426,6 +436,11 @@ class ExposeMacro(Macro):
     expose_helper: ExposeHelper
     _pause_event = asyncio.Event()
 
+    def __init__(self):
+        super().__init__()
+
+        self.configuration: Configuration | None = None
+
     def _reset_internal(self, **opts):
         """Reset the exposure status."""
 
@@ -508,6 +523,11 @@ class ExposeMacro(Macro):
 
         await asyncio.gather(*tasks)
 
+        # If we are about to expose that means the goto-field is done, so let's mark it.
+        # This is useful in cases where the goto failed and it was manually completed.
+        if self.helpers.jaeger.configuration:
+            self.helpers.jaeger.configuration.goto_complete = True
+
         # Tell the helper that we're about to start exposing.
         await self.expose_helper.start()
 
@@ -592,6 +612,9 @@ class ExposeMacro(Macro):
             else:
                 self.command.warning("BOSS exposure is running. Not cancelling it.")
 
+        if not self.failed and not self.cancelled and self.configuration:
+            self.configuration.observed = True
+
     async def _pause(self):
         """Pauses the execution of the macro."""
 
