@@ -139,8 +139,14 @@ class _GotoFieldBaseMacro(Macro):
 
         self.command.info("Reconfiguring FPS array.")
 
-        # This is always safe. If it's already folded jaeger will return immediately.
-        await self.send_command("jaeger", "configuration reverse")
+        if not (await self.helpers.jaeger.is_folded(self.command)):
+            try:
+                await self.send_command("jaeger", "configuration reverse")
+            except MacroError:
+                self.command.warning("Reverse trajectory failed. Will try to unwind.")
+
+                if not (await self.helpers.jaeger.unwind(self.command)):
+                    raise MacroError("Failed unwindind the FPS array.")
 
         await self.send_command("jaeger", "configuration execute")
 
@@ -271,6 +277,8 @@ class _GotoFieldBaseMacro(Macro):
     async def acquire(self):
         """Acquires the field."""
 
+        self._mark_design_as_goto_complete()
+
         if self.helpers.cherno.is_guiding():
             self.command.info("Already guiding.")
             return
@@ -280,6 +288,8 @@ class _GotoFieldBaseMacro(Macro):
         acquisition_config = self.config["acquisition"][self.observatory]
 
         exposure_time = acquisition_config["exposure_time"]
+        max_exposure_time = acquisition_config["max_exposure_time"]
+        dynamic_exposure_time = acquisition_config["dynamic_exposure_time"]
         target_rms = acquisition_config["target_rms"]
         min_rms = acquisition_config["min_rms"]
         max_iterations = acquisition_config["max_iterations"]
@@ -291,6 +301,8 @@ class _GotoFieldBaseMacro(Macro):
             await self.helpers.cherno.acquire(
                 self.command,
                 exposure_time=exposure_time,
+                max_exposure_time=max_exposure_time,
+                dynamic_exposure_time=dynamic_exposure_time,
                 target_rms=target_rms,
                 max_iterations=max_iterations,
                 wait_time=wait_time,
@@ -310,6 +322,8 @@ class _GotoFieldBaseMacro(Macro):
     async def guide(self):
         """Starts the guide loop."""
 
+        self._mark_design_as_goto_complete()
+
         if self.helpers.cherno.is_guiding():
             self.command.info("Already guiding.")
             return
@@ -317,11 +331,15 @@ class _GotoFieldBaseMacro(Macro):
         await self._guide_preconditions("guide")
 
         guide_config = self.config["guide"][self.observatory]
+        if self.config["guider_time"] is not None:
+            exposure_time = self.config["guider_time"]
+        else:
+            exposure_time = guide_config["exposure_time"]
 
         self.command.info("Starting guide loop.")
         await self.helpers.cherno.guide(
             self.command,
-            exposure_time=guide_config["exposure_time"],
+            exposure_time=exposure_time,
             wait_time=guide_config["wait_time"],
             wait=False,
         )
@@ -333,8 +351,7 @@ class _GotoFieldBaseMacro(Macro):
             await asyncio.sleep(3)
 
         # If enough stages have run, mark this configuration as goto_complete.
-        if self.helpers.jaeger.configuration is not None and self._is_goto_complete():
-            self.helpers.jaeger.configuration.goto_complete = True
+        self._mark_design_as_goto_complete()
 
         if self._lamps_task is not None and not self._lamps_task.done():
             self._lamps_task.cancel()
@@ -345,6 +362,15 @@ class _GotoFieldBaseMacro(Macro):
         if self.helpers.boss.readout_pending:
             await self.helpers.boss.readout(self.command)
 
+    def _mark_design_as_goto_complete(self):
+        """Marks the design as goto_complete."""
+
+        if self.helpers.jaeger.configuration is not None:
+            if self._is_goto_complete():
+                self.helpers.jaeger.configuration.goto_complete = True
+            else:
+                self.helpers.jaeger.configuration.goto_complete = False
+
     def _get_pointing(self):
         """Returns the configuration pointing."""
 
@@ -385,7 +411,7 @@ class _GotoFieldBaseMacro(Macro):
         """
 
         for stage in self.flat_stages:
-            if stage == "acquire" or stage == "guide":
+            if stage in ["acquire", "guide", "cleanup"]:
                 continue
             if not self.is_stage_done(stage):
                 return False
